@@ -20,7 +20,7 @@ Vue.component('edit-field', {
         example: { }
     },
     data: function () {
-        var schemaType, fieldType = 'text',
+        var schemaType, fieldType = 'text', inputMode = 'text',
             pattern = this.schema.pattern;
 
         if ( Array.isArray( this.schema.type ) ) {
@@ -42,12 +42,15 @@ Vue.component('edit-field', {
             }
             else if ( this.schema.format == 'email' ) {
                 fieldType = 'email';
+                inputMode = 'email';
             }
             else if ( this.schema.format == 'url' ) {
                 fieldType = 'url';
+                inputMode = 'url';
             }
             else if ( this.schema.format == 'tel' ) {
                 fieldType = 'tel';
+                inputMode = 'tel';
             }
             else if ( this.schema.format == 'password' ) {
                 fieldType = 'password';
@@ -64,8 +67,12 @@ Vue.component('edit-field', {
         }
         else if ( schemaType == 'integer' || schemaType == 'number' ) {
             fieldType = 'number';
+            inputMode = 'decimal';
             if ( schemaType == 'integer' ) {
-                pattern = this.schema.pattern || '^\\d+$';
+                // Use pattern to show numeric input on iOS
+                // https://css-tricks.com/finger-friendly-numerical-inputs-with-inputmode/
+                pattern = this.schema.pattern || '[0-9]*';
+                inputMode = 'numeric';
             }
         }
 
@@ -78,6 +85,7 @@ Vue.component('edit-field', {
             max: this.schema.maximum,
             readonly: this.schema.readOnly,
             writeonly: this.schema.writeOnly,
+            inputMode: inputMode,
             _value: this.value,
             showHtml: false
         };
